class Librespot < Formula
  desc "Open Source Spotify client library"
  homepage "https://github.com/librespot-org/librespot"
  license "MIT"
  head "https://github.com/librespot-org/librespot.git", branch: "dev"

  stable do
    url "https://github.com/librespot-org/librespot/archive/refs/tags/v0.4.2.tar.gz"
    sha256 "cc8cb81bdbaa5abf366170dec5e6b8c0ecf570a7cb68f04483e9f7eed338ca61"

    # Use `llvm@15` to work around build failure with LLVM Clang 16 (Apple Clang 15)
    # described in https://github.com/rust-lang/rust-bindgen/issues/2312.
    # TODO: Remove in the next release
    depends_on "llvm@15" => :build if DevelopmentTools.clang_build_version >= 1500
  end

  depends_on "rust" => :build

  on_linux do
    depends_on "pkg-config" => :build
    depends_on "alsa-lib"
    depends_on "avahi"
  end

  def install
    odie "Check if `llvm@15` dependency can be removed!" if build.stable? && version > "0.4.2"
    ENV.remove "HOMEBREW_LIBRARY_PATHS", Formula["llvm@15"].opt_lib

    ENV["COREAUDIO_SDK_PATH"] = MacOS.sdk_path.to_s if OS.mac?
    system "cargo", "install", "--no-default-features", "--features", "rodio-backend,with-dns-sd", *std_cargo_args
  end

  test do
    require "open3"
    require "timeout"

    Open3.popen3({ "RUST_LOG" => "DEBUG" }, "#{bin}/librespot", "-v") do |_, _, stderr, wait_thr|
      Timeout.timeout(5) do
        stderr.each do |line|
          refute_match "ERROR", line
          break if line.include? "Zeroconf server listening"
        end
      end
    ensure
      Process.kill("INT", wait_thr.pid)
    end
  end
end
